.. Autogenerated by genmods.py

.. _api-index:

##############################################################################
   Reference
##############################################################################

.. only:: html

   :Release: |version|
   :Date: |today|

.. toctree::

   core.rst
   formulas.rst
   covalent_radius.rst
   constants.rst
   crystal_structure.rst
   density.rst
   fasta.rst
   magnetic_ff.rst
   mass.rst
   activation.rst
   nsf.rst
   xsf.rst
   cromermann.rst
   plot.rst
   util.rst
